package com.hfkj.service.item.impl;

import com.hfkj.dao.EnItemSegmentsMapper;
import com.hfkj.entity.EnItem;
import com.hfkj.entity.EnItemSegments;
import com.hfkj.entity.EnItemSegmentsExample;
import com.hfkj.service.item.EnItemSegmentsService;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Collections;
import java.util.Date;
import java.util.List;
import java.util.Map;

@Service("enItemSegmentsService")
public class EnItemSegmentsServiceImpl implements EnItemSegmentsService {

    @Resource
    private EnItemSegmentsMapper enItemSegmentsMapper;

    @Override
    public void create(EnItemSegments enItemSegments) {
        enItemSegmentsMapper.insert(enItemSegments);
    }

    @Override
    public void update(EnItemSegments enItemSegments) {
        enItemSegmentsMapper.updateByPrimaryKey(enItemSegments);
    }

    @Override
    public void delete(Long id, Boolean fullDelete) {
        if (fullDelete) {
            enItemSegmentsMapper.deleteByPrimaryKey(id);
        } else {
            EnItemSegments enItemSegments = queryDetail(id);
            enItemSegments.setStatus(0);
            enItemSegments.setUpdateTime(new Date());
            update(enItemSegments);
        }
    }

    @Override
    public EnItemSegments queryDetail(Long id) {
        return enItemSegmentsMapper.selectByPrimaryKey(id);
    }

    @Override
    public EnItemSegments queryDetailByMap(Map<String, Object> map) {
        EnItemSegmentsExample example = new EnItemSegmentsExample();
        EnItemSegmentsExample.Criteria criteria = example.createCriteria();

        if (MapUtils.getLong(map, "itemId") != null) {
            criteria.andItemIdEqualTo(MapUtils.getLong(map, "itemId"));
        }
        if (MapUtils.getLong(map , "oilDepotId") != null) {
            criteria.andOilDepotIdEqualTo(MapUtils.getLong(map, "oilDepotId"));
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "segmentName"))) {
            criteria.andSegmentNameLike("%"+MapUtils.getString(map, "segmentName")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "address"))) {
            criteria.andAddressLike("%"+MapUtils.getString(map, "address")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "person"))) {
            criteria.andPersonLike("%"+MapUtils.getString(map, "person")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "contactInfo"))) {
            criteria.andContactInfoLike("%"+MapUtils.getString(map, "contactInfo")+"%");
        }
        if (MapUtils.getLong(map, "createUser") != null) {
            criteria.andCreateUserEqualTo(MapUtils.getLong(map, "createUser"));
        }
        if (MapUtils.getInteger(map, "status") != null) {
            criteria.andStatusEqualTo(MapUtils.getInteger(map, "status"));
        }else {
            criteria.andStatusNotEqualTo(0);
        }
        if (MapUtils.getLong(map , "id") != null) {
            criteria.andIdEqualTo(MapUtils.getLong(map , "id"));
        }

        List<EnItemSegments> list = enItemSegmentsMapper.selectByExample(example);

        return list.isEmpty()?null:list.get(0);
    }

    @Override
    public List<EnItemSegments> getList(Map<String, Object> map) {
        EnItemSegmentsExample example = new EnItemSegmentsExample();
        EnItemSegmentsExample.Criteria criteria = example.createCriteria();

        if (MapUtils.getLong(map, "itemId") != null) {
            criteria.andItemIdEqualTo(MapUtils.getLong(map, "itemId"));
        }
        if (MapUtils.getLong(map , "oilDepotId") != null) {
            criteria.andOilDepotIdEqualTo(MapUtils.getLong(map, "oilDepotId"));
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "segmentName"))) {
            criteria.andSegmentNameLike("%"+MapUtils.getString(map, "segmentName")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "address"))) {
            criteria.andAddressLike("%"+MapUtils.getString(map, "address")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "person"))) {
            criteria.andPersonLike("%"+MapUtils.getString(map, "person")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "contactInfo"))) {
            criteria.andContactInfoLike("%"+MapUtils.getString(map, "contactInfo")+"%");
        }
        if (MapUtils.getLong(map, "createUser") != null) {
            criteria.andCreateUserEqualTo(MapUtils.getLong(map, "createUser"));
        }
        if (MapUtils.getInteger(map, "status") != null) {
            criteria.andStatusEqualTo(MapUtils.getInteger(map, "status"));
        }else {
            criteria.andStatusNotEqualTo(0);
        }

        return enItemSegmentsMapper.selectByExample(example);
    }
}
